package App::lcpan::CmdBundle::deps;

our $DATE = '2017-01-20'; # DATE
our $VERSION = '0.005'; # VERSION

1;
# ABSTRACT: More lcpan subcommands related to dependencies

__END__

=pod

=encoding UTF-8

=head1 NAME

App::lcpan::CmdBundle::deps - More lcpan subcommands related to dependencies

=head1 VERSION

This document describes version 0.005 of App::lcpan::CmdBundle::deps (from Perl distribution App-lcpan-CmdBundle-deps), released on 2017-01-20.

=head1 SYNOPSIS

=head1 DESCRIPTION

This bundle provides the following lcpan subcommands:

=over

=item * L<lcpan deps-all|App::lcpan::Cmd::deps_all>

=back

These subcommands might be added to App-lcpan, but right now they are more
experimental and/or useful only for specific cases.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/App-lcpan-CmdBundle-deps>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-App-lcpan-CmdBundle-deps>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-lcpan-CmdBundle-deps>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

L<lcpan>

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2017 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
